@@ -14,8 +14,8 @@ module EC2Version
   MANIFEST_CLASS = ManifestV20071010
   MANIFEST_VERSION = MANIFEST_CLASS.version
   PKG_NAME = 'ec2-ami-tools'
-  PKG_VERSION = '1.3'
-  PKG_RELEASE = '66634'
+  PKG_VERSION = '1.4'
+  PKG_RELEASE = '0.2'
 
   COPYRIGHT_NOTICE = <<CNOTICE
 Copyright 2008-2009 Amazon.com, Inc. or its affiliates.  All Rights Reserved.
@@ -28,6 +28,6 @@ specific language governing permissions and limitations under the License.
 CNOTICE
   
   def self.version_copyright_string()
-    "#{PKG_VERSION}-#{PKG_RELEASE} #{MANIFEST_VERSION}\n\n" + COPYRIGHT_NOTICE + "\n"
+    "#{PKG_VERSION}.#{PKG_RELEASE} #{MANIFEST_VERSION}\n\n" + COPYRIGHT_NOTICE + "\n"
   end
 end
